`include "modport.svh"

module hps_wrapper (
    // FPGA -> HPS Reset and interrupt
    input  wire          a10_hps_f2h_cold_reset_n,
    input  wire          a10_hps_f2h_debug_reset_n,
    input  wire          a10_hps_f2h_warm_reset_n,
    input  wire [31:0]   a10_hps_f2h_irq0,
    input  wire [31:0]   a10_hps_f2h_irq1,
    input  wire [27:0]   a10_hps_f2h_stm_hw_events,

    // HPS -> FPGA AXI MASTER
    input  wire          a10_hps_h2f_axi_master_clk,
    input  wire          a10_hps_h2f_axi_master_reset_n,
    `MODPORT(axi4_mm_if, master) a10_hps_h2f_axi_master,

    // HPS -> FPGA AXI MASTER LIGHTWEIGHT
    input  wire          a10_hps_h2f_lw_axi_master_clk,
    input  wire          a10_hps_h2f_lw_axi_master_reset_n,
    `MODPORT(axi4_mm_if, master) a10_hps_h2f_lw_axi_master,

    // FPGA -> HPS AXI SLAVE
    input  wire          a10_hps_f2h_axi_slave_clk,
    input  wire          a10_hps_f2h_axi_slave_reset_n,
    `MODPORT(axi4_mm_if, slave)  a10_hps_f2h_axi_slave,

    // DDR4 single rank -2133 device
    input  wire          emif_ref_clk,
    input  wire          emif_reset_n,
    output wire          hps_memory_mem_act_n,
    output wire          hps_memory_mem_bg,
    output wire          hps_memory_mem_par,
    input  wire          hps_memory_mem_alert_n,
    inout  wire [ 3:0]   hps_memory_mem_dbi_n,
    output wire [16:0]   hps_memory_mem_a,
    output wire [ 1:0]   hps_memory_mem_ba,
    output wire          hps_memory_mem_ck,
    output wire          hps_memory_mem_ck_n,
    output wire          hps_memory_mem_cke,
    output wire          hps_memory_mem_cs_n,
    output wire          hps_memory_mem_reset_n,
    inout  wire [31:0]   hps_memory_mem_dq,
    inout  wire [ 3:0]   hps_memory_mem_dqs,
    inout  wire [ 3:0]   hps_memory_mem_dqs_n,
    output wire          hps_memory_mem_odt,
    input  wire          hps_memory_oct_rzqin,

    // HPS peripherals
    output wire          a10_hps_phery_emac0_TX_CLK,
    output wire          a10_hps_phery_emac0_TXD0,
    output wire          a10_hps_phery_emac0_TXD1,
    output wire          a10_hps_phery_emac0_TXD2,
    output wire          a10_hps_phery_emac0_TXD3,
    input  wire          a10_hps_phery_emac0_RX_CTL,
    output wire          a10_hps_phery_emac0_TX_CTL,
    input  wire          a10_hps_phery_emac0_RX_CLK,
    input  wire          a10_hps_phery_emac0_RXD0,
    input  wire          a10_hps_phery_emac0_RXD1,
    input  wire          a10_hps_phery_emac0_RXD2,
    input  wire          a10_hps_phery_emac0_RXD3,
    inout  wire          a10_hps_phery_emac0_MDIO,
    output wire          a10_hps_phery_emac0_MDC,
    inout  wire          a10_hps_phery_sdmmc_CMD,
    inout  wire          a10_hps_phery_sdmmc_D0,
    inout  wire          a10_hps_phery_sdmmc_D1,
    inout  wire          a10_hps_phery_sdmmc_D2,
    inout  wire          a10_hps_phery_sdmmc_D3,
    inout  wire          a10_hps_phery_sdmmc_D4,
    inout  wire          a10_hps_phery_sdmmc_D5,
    inout  wire          a10_hps_phery_sdmmc_D6,
    inout  wire          a10_hps_phery_sdmmc_D7,
    output wire          a10_hps_phery_sdmmc_CCLK,
    inout  wire          a10_hps_phery_usb0_DATA0,
    inout  wire          a10_hps_phery_usb0_DATA1,
    inout  wire          a10_hps_phery_usb0_DATA2,
    inout  wire          a10_hps_phery_usb0_DATA3,
    inout  wire          a10_hps_phery_usb0_DATA4,
    inout  wire          a10_hps_phery_usb0_DATA5,
    inout  wire          a10_hps_phery_usb0_DATA6,
    inout  wire          a10_hps_phery_usb0_DATA7,
    input  wire          a10_hps_phery_usb0_CLK,
    output wire          a10_hps_phery_usb0_STP,
    input  wire          a10_hps_phery_usb0_DIR,
    input  wire          a10_hps_phery_usb0_NXT,
    output wire          a10_hps_phery_spim1_CLK,
    output wire          a10_hps_phery_spim1_MOSI,
    input  wire          a10_hps_phery_spim1_MISO,
    output wire          a10_hps_phery_spim1_SS0_N,
    output wire          a10_hps_phery_spim1_SS1_N,
    input  wire          a10_hps_phery_uart1_RX,
    output wire          a10_hps_phery_uart1_TX,
    inout  wire          a10_hps_phery_i2c1_SDA,
    inout  wire          a10_hps_phery_i2c1_SCL
);

// ---------------------------------------
// ------- HPS -> FPGA AXI MASTER --------
// ---------------------------------------
// Write address channel
wire [3:0]    a10_hps_h2f_axi_master_awid;
wire [31:0]   a10_hps_h2f_axi_master_awaddr;
wire [3:0]    a10_hps_h2f_axi_master_awlen;
wire [2:0]    a10_hps_h2f_axi_master_awsize;
wire [1:0]    a10_hps_h2f_axi_master_awburst;
wire [1:0]    a10_hps_h2f_axi_master_awlock;
wire [3:0]    a10_hps_h2f_axi_master_awcache;
wire [2:0]    a10_hps_h2f_axi_master_awprot;
wire          a10_hps_h2f_axi_master_awvalid;
wire          a10_hps_h2f_axi_master_awready;
wire [4:0]    a10_hps_h2f_axi_master_awuser;

// Write data channel
wire [3:0]    a10_hps_h2f_axi_master_wid;
wire [63:0]   a10_hps_h2f_axi_master_wdata;
wire [7:0]    a10_hps_h2f_axi_master_wstrb;
wire          a10_hps_h2f_axi_master_wlast;
wire          a10_hps_h2f_axi_master_wvalid;
wire          a10_hps_h2f_axi_master_wready;

// Write response channel
wire [3:0]    a10_hps_h2f_axi_master_bid;
wire [1:0]    a10_hps_h2f_axi_master_bresp;
wire          a10_hps_h2f_axi_master_bvalid;
wire          a10_hps_h2f_axi_master_bready;

// Read address channel
wire [3:0]    a10_hps_h2f_axi_master_arid;
wire [31:0]   a10_hps_h2f_axi_master_araddr;
wire [3:0]    a10_hps_h2f_axi_master_arlen;
wire [2:0]    a10_hps_h2f_axi_master_arsize;
wire [1:0]    a10_hps_h2f_axi_master_arburst;
wire [1:0]    a10_hps_h2f_axi_master_arlock;
wire [3:0]    a10_hps_h2f_axi_master_arcache;
wire [2:0]    a10_hps_h2f_axi_master_arprot;
wire          a10_hps_h2f_axi_master_arvalid;
wire          a10_hps_h2f_axi_master_arready;
wire [4:0]    a10_hps_h2f_axi_master_aruser;

// Read data channel
wire [3:0]    a10_hps_h2f_axi_master_rid;
wire [63:0]   a10_hps_h2f_axi_master_rdata;
wire [1:0]    a10_hps_h2f_axi_master_rresp;
wire          a10_hps_h2f_axi_master_rlast;
wire          a10_hps_h2f_axi_master_rvalid;
wire          a10_hps_h2f_axi_master_rready;

// ---------------------------------------
// ----- HPS -> FPGA AXI MASTER LW -------
// ---------------------------------------
// Write address channel
wire [3:0]    a10_hps_h2f_lw_axi_master_awid;
wire [20:0]   a10_hps_h2f_lw_axi_master_awaddr;
wire [3:0]    a10_hps_h2f_lw_axi_master_awlen;
wire [2:0]    a10_hps_h2f_lw_axi_master_awsize;
wire [1:0]    a10_hps_h2f_lw_axi_master_awburst;
wire [1:0]    a10_hps_h2f_lw_axi_master_awlock;
wire [3:0]    a10_hps_h2f_lw_axi_master_awcache;
wire [2:0]    a10_hps_h2f_lw_axi_master_awprot;
wire          a10_hps_h2f_lw_axi_master_awvalid;
wire          a10_hps_h2f_lw_axi_master_awready;
wire [4:0]    a10_hps_h2f_lw_axi_master_awuser;

assign a10_hps_h2f_lw_axi_master.awid     = a10_hps_h2f_lw_axi_master_awid;
assign a10_hps_h2f_lw_axi_master.awaddr   = a10_hps_h2f_lw_axi_master_awaddr;
assign a10_hps_h2f_lw_axi_master.awlen    = a10_hps_h2f_lw_axi_master_awlen;
assign a10_hps_h2f_lw_axi_master.awsize   = a10_hps_h2f_lw_axi_master_awsize;
assign a10_hps_h2f_lw_axi_master.awburst  = a10_hps_h2f_lw_axi_master_awburst;
assign a10_hps_h2f_lw_axi_master.awlock   = a10_hps_h2f_lw_axi_master_awlock;
assign a10_hps_h2f_lw_axi_master.awcache  = a10_hps_h2f_lw_axi_master_awcache;
assign a10_hps_h2f_lw_axi_master.awprot   = a10_hps_h2f_lw_axi_master_awprot;
assign a10_hps_h2f_lw_axi_master.awqos    = '0;
assign a10_hps_h2f_lw_axi_master.awregion = '0;
assign a10_hps_h2f_lw_axi_master.awuser   = '0;
assign a10_hps_h2f_lw_axi_master.awvalid  = a10_hps_h2f_lw_axi_master_awvalid;
assign a10_hps_h2f_lw_axi_master_awready  = a10_hps_h2f_lw_axi_master.awready;


// Write data channel
wire [3:0]    a10_hps_h2f_lw_axi_master_wid;
wire [31:0]   a10_hps_h2f_lw_axi_master_wdata;
wire [3:0]    a10_hps_h2f_lw_axi_master_wstrb;
wire          a10_hps_h2f_lw_axi_master_wlast;
wire          a10_hps_h2f_lw_axi_master_wvalid;
wire          a10_hps_h2f_lw_axi_master_wready;

assign a10_hps_h2f_lw_axi_master.wid      = a10_hps_h2f_lw_axi_master_wid;
assign a10_hps_h2f_lw_axi_master.wdata[0] = a10_hps_h2f_lw_axi_master_wdata[ 7: 0];
assign a10_hps_h2f_lw_axi_master.wdata[1] = a10_hps_h2f_lw_axi_master_wdata[15: 8];
assign a10_hps_h2f_lw_axi_master.wdata[2] = a10_hps_h2f_lw_axi_master_wdata[23:16];
assign a10_hps_h2f_lw_axi_master.wdata[3] = a10_hps_h2f_lw_axi_master_wdata[31:24];
assign a10_hps_h2f_lw_axi_master.wstrb    = a10_hps_h2f_lw_axi_master_wstrb;
assign a10_hps_h2f_lw_axi_master.wlast    = a10_hps_h2f_lw_axi_master_wlast;
assign a10_hps_h2f_lw_axi_master.wuser    = '0;
assign a10_hps_h2f_lw_axi_master.wvalid   = a10_hps_h2f_lw_axi_master_wvalid;
assign a10_hps_h2f_lw_axi_master_wready   = a10_hps_h2f_lw_axi_master.wready;

// Write response channel
wire [3:0]    a10_hps_h2f_lw_axi_master_bid;
wire [1:0]    a10_hps_h2f_lw_axi_master_bresp;
wire          a10_hps_h2f_lw_axi_master_bvalid;
wire          a10_hps_h2f_lw_axi_master_bready;

assign a10_hps_h2f_lw_axi_master_bid    = a10_hps_h2f_lw_axi_master.bid;
assign a10_hps_h2f_lw_axi_master_bresp  = a10_hps_h2f_lw_axi_master.bresp;
assign a10_hps_h2f_lw_axi_master_bvalid = a10_hps_h2f_lw_axi_master.bvalid;
assign a10_hps_h2f_lw_axi_master.bready = a10_hps_h2f_lw_axi_master_bready;

// Read address channel
wire [3:0]    a10_hps_h2f_lw_axi_master_arid;
wire [20:0]   a10_hps_h2f_lw_axi_master_araddr;
wire [3:0]    a10_hps_h2f_lw_axi_master_arlen;
wire [2:0]    a10_hps_h2f_lw_axi_master_arsize;
wire [1:0]    a10_hps_h2f_lw_axi_master_arburst;
wire [1:0]    a10_hps_h2f_lw_axi_master_arlock;
wire [3:0]    a10_hps_h2f_lw_axi_master_arcache;
wire [2:0]    a10_hps_h2f_lw_axi_master_arprot;
wire          a10_hps_h2f_lw_axi_master_arvalid;
wire          a10_hps_h2f_lw_axi_master_arready;
wire [4:0]    a10_hps_h2f_lw_axi_master_aruser;

assign a10_hps_h2f_lw_axi_master.arid     = a10_hps_h2f_lw_axi_master_arid;
assign a10_hps_h2f_lw_axi_master.araddr   = a10_hps_h2f_lw_axi_master_araddr;
assign a10_hps_h2f_lw_axi_master.arlen    = a10_hps_h2f_lw_axi_master_arlen;
assign a10_hps_h2f_lw_axi_master.arsize   = a10_hps_h2f_lw_axi_master_arsize;
assign a10_hps_h2f_lw_axi_master.arburst  = a10_hps_h2f_lw_axi_master_arburst;
assign a10_hps_h2f_lw_axi_master.arlock   = a10_hps_h2f_lw_axi_master_arlock;
assign a10_hps_h2f_lw_axi_master.arcache  = a10_hps_h2f_lw_axi_master_arcache;
assign a10_hps_h2f_lw_axi_master.arprot   = a10_hps_h2f_lw_axi_master_arprot;
assign a10_hps_h2f_lw_axi_master.arqos    = '0;
assign a10_hps_h2f_lw_axi_master.arregion = '0;
assign a10_hps_h2f_lw_axi_master.aruser   = '0;
assign a10_hps_h2f_lw_axi_master.arvalid  = a10_hps_h2f_lw_axi_master_arvalid;
assign a10_hps_h2f_lw_axi_master_arready  = a10_hps_h2f_lw_axi_master.arready;


// Read data channel
wire [3:0]    a10_hps_h2f_lw_axi_master_rid;
wire [31:0]   a10_hps_h2f_lw_axi_master_rdata;
wire [1:0]    a10_hps_h2f_lw_axi_master_rresp;
wire          a10_hps_h2f_lw_axi_master_rlast;
wire          a10_hps_h2f_lw_axi_master_rvalid;
wire          a10_hps_h2f_lw_axi_master_rready;

assign a10_hps_h2f_lw_axi_master_rid          = a10_hps_h2f_lw_axi_master.rid;
assign a10_hps_h2f_lw_axi_master_rdata[ 7: 0] = a10_hps_h2f_lw_axi_master.rdata[0];
assign a10_hps_h2f_lw_axi_master_rdata[15: 8] = a10_hps_h2f_lw_axi_master.rdata[1];
assign a10_hps_h2f_lw_axi_master_rdata[23:16] = a10_hps_h2f_lw_axi_master.rdata[2];
assign a10_hps_h2f_lw_axi_master_rdata[31:24] = a10_hps_h2f_lw_axi_master.rdata[3];
assign a10_hps_h2f_lw_axi_master_rresp        = a10_hps_h2f_lw_axi_master.rresp;
assign a10_hps_h2f_lw_axi_master_rlast        = a10_hps_h2f_lw_axi_master.rlast;
assign a10_hps_h2f_lw_axi_master_rvalid       = a10_hps_h2f_lw_axi_master.rvalid;
assign a10_hps_h2f_lw_axi_master.rready       = a10_hps_h2f_lw_axi_master_rready;

// ---------------------------------------
// ------- FPGA -> HPS AXI SLAVE ---------
// ---------------------------------------
wire [3:0]    a10_hps_f2h_axi_slave_awid;
wire [31:0]   a10_hps_f2h_axi_slave_awaddr;
wire [3:0]    a10_hps_f2h_axi_slave_awlen;
wire [2:0]    a10_hps_f2h_axi_slave_awsize;
wire [1:0]    a10_hps_f2h_axi_slave_awburst;
wire [1:0]    a10_hps_f2h_axi_slave_awlock;
wire [3:0]    a10_hps_f2h_axi_slave_awcache;
wire [2:0]    a10_hps_f2h_axi_slave_awprot;
wire          a10_hps_f2h_axi_slave_awvalid;
wire          a10_hps_f2h_axi_slave_awready;
wire [4:0]    a10_hps_f2h_axi_slave_awuser;
wire [3:0]    a10_hps_f2h_axi_slave_wid;
wire [63:0]   a10_hps_f2h_axi_slave_wdata;
wire [7:0]    a10_hps_f2h_axi_slave_wstrb;
wire          a10_hps_f2h_axi_slave_wlast;
wire          a10_hps_f2h_axi_slave_wvalid;
wire          a10_hps_f2h_axi_slave_wready;
wire [3:0]    a10_hps_f2h_axi_slave_bid;
wire [1:0]    a10_hps_f2h_axi_slave_bresp;
wire          a10_hps_f2h_axi_slave_bvalid;
wire          a10_hps_f2h_axi_slave_bready;
wire [3:0]    a10_hps_f2h_axi_slave_arid;
wire [31:0]   a10_hps_f2h_axi_slave_araddr;
wire [3:0]    a10_hps_f2h_axi_slave_arlen;
wire [2:0]    a10_hps_f2h_axi_slave_arsize;
wire [1:0]    a10_hps_f2h_axi_slave_arburst;
wire [1:0]    a10_hps_f2h_axi_slave_arlock;
wire [3:0]    a10_hps_f2h_axi_slave_arcache;
wire [2:0]    a10_hps_f2h_axi_slave_arprot;
wire          a10_hps_f2h_axi_slave_arvalid;
wire          a10_hps_f2h_axi_slave_arready;
wire [4:0]    a10_hps_f2h_axi_slave_aruser;
wire [3:0]    a10_hps_f2h_axi_slave_rid;
wire [63:0]   a10_hps_f2h_axi_slave_rdata;
wire [1:0]    a10_hps_f2h_axi_slave_rresp;
wire          a10_hps_f2h_axi_slave_rlast;
wire          a10_hps_f2h_axi_slave_rvalid;
wire          a10_hps_f2h_axi_slave_rready;

// EMIF conduits
wire [4095:0] emif_a10_hps_conduit_end_hps_to_emif;
wire [4095:0] emif_a10_hps_conduit_end_emif_to_hps;
wire [1:0]    emif_a10_hps_conduit_end_gp_to_emif;
wire [0:0]    emif_a10_hps_conduit_end_emif_to_gp;

arria10_hps hps_inst (
    .a10_hps_emif_emif_to_hps               (emif_a10_hps_conduit_end_emif_to_hps),
    .a10_hps_emif_hps_to_emif               (emif_a10_hps_conduit_end_hps_to_emif),
    .a10_hps_emif_emif_to_gp                (emif_a10_hps_conduit_end_emif_to_gp),
    .a10_hps_emif_gp_to_emif                (emif_a10_hps_conduit_end_gp_to_emif),

    .a10_hps_f2h_cold_reset_req_reset_n     (a10_hps_f2h_cold_reset_n),
    .a10_hps_f2h_debug_reset_req_reset_n    (a10_hps_f2h_debug_reset_n),
    .a10_hps_f2h_irq0_irq                   (a10_hps_f2h_irq0),
    .a10_hps_f2h_irq1_irq                   (a10_hps_f2h_irq1),
    .a10_hps_f2h_stm_hw_events_stm_hwevents (a10_hps_f2h_stm_hw_events),
    .a10_hps_f2h_warm_reset_req_reset_n     (a10_hps_f2h_warm_reset_n),

    .a10_hps_h2f_reset_reset_n              (),

    .a10_hps_f2h_axi_slave_clock_clk        (a10_hps_f2h_axi_slave_clk),
    .a10_hps_f2h_axi_slave_reset_reset_n    (a10_hps_f2h_axi_slave_reset_n),
    .a10_hps_f2h_axi_slave_awid             (a10_hps_f2h_axi_slave_awid),
    .a10_hps_f2h_axi_slave_awaddr           (a10_hps_f2h_axi_slave_awaddr),
    .a10_hps_f2h_axi_slave_awlen            (a10_hps_f2h_axi_slave_awlen),
    .a10_hps_f2h_axi_slave_awsize           (a10_hps_f2h_axi_slave_awsize),
    .a10_hps_f2h_axi_slave_awburst          (a10_hps_f2h_axi_slave_awburst),
    .a10_hps_f2h_axi_slave_awlock           (a10_hps_f2h_axi_slave_awlock),
    .a10_hps_f2h_axi_slave_awcache          (a10_hps_f2h_axi_slave_awcache),
    .a10_hps_f2h_axi_slave_awprot           (a10_hps_f2h_axi_slave_awprot),
    .a10_hps_f2h_axi_slave_awvalid          (a10_hps_f2h_axi_slave_awvalid),
    .a10_hps_f2h_axi_slave_awready          (a10_hps_f2h_axi_slave_awready),
    .a10_hps_f2h_axi_slave_awuser           (a10_hps_f2h_axi_slave_awuser),
    .a10_hps_f2h_axi_slave_wid              (a10_hps_f2h_axi_slave_wid),
    .a10_hps_f2h_axi_slave_wdata            (a10_hps_f2h_axi_slave_wdata),
    .a10_hps_f2h_axi_slave_wstrb            (a10_hps_f2h_axi_slave_wstrb),
    .a10_hps_f2h_axi_slave_wlast            (a10_hps_f2h_axi_slave_wlast),
    .a10_hps_f2h_axi_slave_wvalid           (a10_hps_f2h_axi_slave_wvalid),
    .a10_hps_f2h_axi_slave_wready           (a10_hps_f2h_axi_slave_wready),
    .a10_hps_f2h_axi_slave_bid              (a10_hps_f2h_axi_slave_bid),
    .a10_hps_f2h_axi_slave_bresp            (a10_hps_f2h_axi_slave_bresp),
    .a10_hps_f2h_axi_slave_bvalid           (a10_hps_f2h_axi_slave_bvalid),
    .a10_hps_f2h_axi_slave_bready           (a10_hps_f2h_axi_slave_bready),
    .a10_hps_f2h_axi_slave_arid             (a10_hps_f2h_axi_slave_arid),
    .a10_hps_f2h_axi_slave_araddr           (a10_hps_f2h_axi_slave_araddr),
    .a10_hps_f2h_axi_slave_arlen            (a10_hps_f2h_axi_slave_arlen),
    .a10_hps_f2h_axi_slave_arsize           (a10_hps_f2h_axi_slave_arsize),
    .a10_hps_f2h_axi_slave_arburst          (a10_hps_f2h_axi_slave_arburst),
    .a10_hps_f2h_axi_slave_arlock           (a10_hps_f2h_axi_slave_arlock),
    .a10_hps_f2h_axi_slave_arcache          (a10_hps_f2h_axi_slave_arcache),
    .a10_hps_f2h_axi_slave_arprot           (a10_hps_f2h_axi_slave_arprot),
    .a10_hps_f2h_axi_slave_arvalid          (a10_hps_f2h_axi_slave_arvalid),
    .a10_hps_f2h_axi_slave_arready          (a10_hps_f2h_axi_slave_arready),
    .a10_hps_f2h_axi_slave_aruser           (a10_hps_f2h_axi_slave_aruser),
    .a10_hps_f2h_axi_slave_rid              (a10_hps_f2h_axi_slave_rid),
    .a10_hps_f2h_axi_slave_rdata            (a10_hps_f2h_axi_slave_rdata),
    .a10_hps_f2h_axi_slave_rresp            (a10_hps_f2h_axi_slave_rresp),
    .a10_hps_f2h_axi_slave_rlast            (a10_hps_f2h_axi_slave_rlast),
    .a10_hps_f2h_axi_slave_rvalid           (a10_hps_f2h_axi_slave_rvalid),
    .a10_hps_f2h_axi_slave_rready           (a10_hps_f2h_axi_slave_rready),


    .axi_clk_clk                            (a10_hps_h2f_lw_axi_master_clk),
    .axi_reset_reset_n                      (a10_hps_h2f_lw_axi_master_reset_n),
    .a10_hps_h2f_lw_axi_master_awid      (a10_hps_h2f_lw_axi_master_awid),
    .a10_hps_h2f_lw_axi_master_awaddr    (a10_hps_h2f_lw_axi_master_awaddr),
    .a10_hps_h2f_lw_axi_master_awlen     (a10_hps_h2f_lw_axi_master_awlen),
    .a10_hps_h2f_lw_axi_master_awsize    (a10_hps_h2f_lw_axi_master_awsize),
    .a10_hps_h2f_lw_axi_master_awburst   (a10_hps_h2f_lw_axi_master_awburst),
    .a10_hps_h2f_lw_axi_master_awlock    (a10_hps_h2f_lw_axi_master_awlock),
    .a10_hps_h2f_lw_axi_master_awcache   (a10_hps_h2f_lw_axi_master_awcache),
    .a10_hps_h2f_lw_axi_master_awprot    (a10_hps_h2f_lw_axi_master_awprot),
    .a10_hps_h2f_lw_axi_master_awuser    (a10_hps_h2f_lw_axi_master_awuser),
    .a10_hps_h2f_lw_axi_master_awvalid   (a10_hps_h2f_lw_axi_master_awvalid),
    .a10_hps_h2f_lw_axi_master_awready   (a10_hps_h2f_lw_axi_master_awready),
    .a10_hps_h2f_lw_axi_master_wdata     (a10_hps_h2f_lw_axi_master_wdata),
    .a10_hps_h2f_lw_axi_master_wstrb     (a10_hps_h2f_lw_axi_master_wstrb),
    .a10_hps_h2f_lw_axi_master_wlast     (a10_hps_h2f_lw_axi_master_wlast),
    .a10_hps_h2f_lw_axi_master_wvalid    (a10_hps_h2f_lw_axi_master_wvalid),
    .a10_hps_h2f_lw_axi_master_wready    (a10_hps_h2f_lw_axi_master_wready),
    .a10_hps_h2f_lw_axi_master_bid       (a10_hps_h2f_lw_axi_master_bid),
    .a10_hps_h2f_lw_axi_master_bresp     (a10_hps_h2f_lw_axi_master_bresp),
    .a10_hps_h2f_lw_axi_master_bvalid    (a10_hps_h2f_lw_axi_master_bvalid),
    .a10_hps_h2f_lw_axi_master_bready    (a10_hps_h2f_lw_axi_master_bready),
    .a10_hps_h2f_lw_axi_master_arid      (a10_hps_h2f_lw_axi_master_arid),
    .a10_hps_h2f_lw_axi_master_araddr    (a10_hps_h2f_lw_axi_master_araddr),
    .a10_hps_h2f_lw_axi_master_arlen     (a10_hps_h2f_lw_axi_master_arlen),
    .a10_hps_h2f_lw_axi_master_arsize    (a10_hps_h2f_lw_axi_master_arsize),
    .a10_hps_h2f_lw_axi_master_arburst   (a10_hps_h2f_lw_axi_master_arburst),
    .a10_hps_h2f_lw_axi_master_arlock    (a10_hps_h2f_lw_axi_master_arlock),
    .a10_hps_h2f_lw_axi_master_arcache   (a10_hps_h2f_lw_axi_master_arcache),
    .a10_hps_h2f_lw_axi_master_arprot    (a10_hps_h2f_lw_axi_master_arprot),
    .a10_hps_h2f_lw_axi_master_aruser    (a10_hps_h2f_lw_axi_master_aruser),
    .a10_hps_h2f_lw_axi_master_arvalid   (a10_hps_h2f_lw_axi_master_arvalid),
    .a10_hps_h2f_lw_axi_master_arready   (a10_hps_h2f_lw_axi_master_arready),
    .a10_hps_h2f_lw_axi_master_rid       (a10_hps_h2f_lw_axi_master_rid),
    .a10_hps_h2f_lw_axi_master_rdata     (a10_hps_h2f_lw_axi_master_rdata),
    .a10_hps_h2f_lw_axi_master_rresp     (a10_hps_h2f_lw_axi_master_rresp),
    .a10_hps_h2f_lw_axi_master_rlast     (a10_hps_h2f_lw_axi_master_rlast),
    .a10_hps_h2f_lw_axi_master_rvalid    (a10_hps_h2f_lw_axi_master_rvalid),
    .a10_hps_h2f_lw_axi_master_rready    (a10_hps_h2f_lw_axi_master_rready),


    .a10_hps_io_hps_io_phery_emac0_TX_CLK   (a10_hps_phery_emac0_TX_CLK),
    .a10_hps_io_hps_io_phery_emac0_TXD0     (a10_hps_phery_emac0_TXD0),
    .a10_hps_io_hps_io_phery_emac0_TXD1     (a10_hps_phery_emac0_TXD1),
    .a10_hps_io_hps_io_phery_emac0_TXD2     (a10_hps_phery_emac0_TXD2),
    .a10_hps_io_hps_io_phery_emac0_TXD3     (a10_hps_phery_emac0_TXD3),
    .a10_hps_io_hps_io_phery_emac0_RX_CTL   (a10_hps_phery_emac0_RX_CTL),
    .a10_hps_io_hps_io_phery_emac0_TX_CTL   (a10_hps_phery_emac0_TX_CTL),
    .a10_hps_io_hps_io_phery_emac0_RX_CLK   (a10_hps_phery_emac0_RX_CLK),
    .a10_hps_io_hps_io_phery_emac0_RXD0     (a10_hps_phery_emac0_RXD0),
    .a10_hps_io_hps_io_phery_emac0_RXD1     (a10_hps_phery_emac0_RXD1),
    .a10_hps_io_hps_io_phery_emac0_RXD2     (a10_hps_phery_emac0_RXD2),
    .a10_hps_io_hps_io_phery_emac0_RXD3     (a10_hps_phery_emac0_RXD3),
    .a10_hps_io_hps_io_phery_emac0_MDIO     (a10_hps_phery_emac0_MDIO),
    .a10_hps_io_hps_io_phery_emac0_MDC      (a10_hps_phery_emac0_MDC),
    .a10_hps_io_hps_io_phery_sdmmc_CMD      (a10_hps_phery_sdmmc_CMD),
    .a10_hps_io_hps_io_phery_sdmmc_D0       (a10_hps_phery_sdmmc_D0),
    .a10_hps_io_hps_io_phery_sdmmc_D1       (a10_hps_phery_sdmmc_D1),
    .a10_hps_io_hps_io_phery_sdmmc_D2       (a10_hps_phery_sdmmc_D2),
    .a10_hps_io_hps_io_phery_sdmmc_D3       (a10_hps_phery_sdmmc_D3),
    .a10_hps_io_hps_io_phery_sdmmc_D4       (a10_hps_phery_sdmmc_D4),
    .a10_hps_io_hps_io_phery_sdmmc_D5       (a10_hps_phery_sdmmc_D5),
    .a10_hps_io_hps_io_phery_sdmmc_D6       (a10_hps_phery_sdmmc_D6),
    .a10_hps_io_hps_io_phery_sdmmc_D7       (a10_hps_phery_sdmmc_D7),
    .a10_hps_io_hps_io_phery_sdmmc_CCLK     (a10_hps_phery_sdmmc_CCLK),
    .a10_hps_io_hps_io_phery_usb0_DATA0     (a10_hps_phery_usb0_DATA0),
    .a10_hps_io_hps_io_phery_usb0_DATA1     (a10_hps_phery_usb0_DATA1),
    .a10_hps_io_hps_io_phery_usb0_DATA2     (a10_hps_phery_usb0_DATA2),
    .a10_hps_io_hps_io_phery_usb0_DATA3     (a10_hps_phery_usb0_DATA3),
    .a10_hps_io_hps_io_phery_usb0_DATA4     (a10_hps_phery_usb0_DATA4),
    .a10_hps_io_hps_io_phery_usb0_DATA5     (a10_hps_phery_usb0_DATA5),
    .a10_hps_io_hps_io_phery_usb0_DATA6     (a10_hps_phery_usb0_DATA6),
    .a10_hps_io_hps_io_phery_usb0_DATA7     (a10_hps_phery_usb0_DATA7),
    .a10_hps_io_hps_io_phery_usb0_CLK       (a10_hps_phery_usb0_CLK),
    .a10_hps_io_hps_io_phery_usb0_STP       (a10_hps_phery_usb0_STP),
    .a10_hps_io_hps_io_phery_usb0_DIR       (a10_hps_phery_usb0_DIR),
    .a10_hps_io_hps_io_phery_usb0_NXT       (a10_hps_phery_usb0_NXT),
    .a10_hps_io_hps_io_phery_spim1_CLK      (a10_hps_phery_spim1_CLK),
    .a10_hps_io_hps_io_phery_spim1_MOSI     (a10_hps_phery_spim1_MOSI),
    .a10_hps_io_hps_io_phery_spim1_MISO     (a10_hps_phery_spim1_MISO),
    .a10_hps_io_hps_io_phery_spim1_SS0_N    (a10_hps_phery_spim1_SS0_N),
    .a10_hps_io_hps_io_phery_spim1_SS1_N    (a10_hps_phery_spim1_SS1_N),
    
    .a10_hps_io_hps_io_phery_uart1_RX       (a10_hps_phery_uart1_RX),
    .a10_hps_io_hps_io_phery_uart1_TX       (a10_hps_phery_uart1_TX),
    .a10_hps_io_hps_io_phery_i2c1_SDA       (a10_hps_phery_i2c1_SDA),
    .a10_hps_io_hps_io_phery_i2c1_SCL       (a10_hps_phery_i2c1_SCL)
);

emif_a10_hps hps_emif_inst (
    .emif_a10_hps_global_reset_reset_sink_reset_n (emif_reset_n),
    .emif_a10_hps_emif_conduit_end_hps_to_emif    (emif_a10_hps_conduit_end_hps_to_emif),
    .emif_a10_hps_emif_conduit_end_emif_to_hps    (emif_a10_hps_conduit_end_emif_to_hps),
    .emif_a10_hps_emif_conduit_end_gp_to_emif     (emif_a10_hps_conduit_end_gp_to_emif),
    .emif_a10_hps_emif_conduit_end_emif_to_gp     (emif_a10_hps_conduit_end_emif_to_gp),
    .emif_a10_hps_mem_conduit_end_mem_ck          (hps_memory_mem_ck),
    .emif_a10_hps_mem_conduit_end_mem_ck_n        (hps_memory_mem_ck_n),
    .emif_a10_hps_mem_conduit_end_mem_a           (hps_memory_mem_a),
    .emif_a10_hps_mem_conduit_end_mem_act_n       (hps_memory_mem_act_n),
    .emif_a10_hps_mem_conduit_end_mem_ba          (hps_memory_mem_ba),
    .emif_a10_hps_mem_conduit_end_mem_bg          (hps_memory_mem_bg),
    .emif_a10_hps_mem_conduit_end_mem_cke         (hps_memory_mem_cke),
    .emif_a10_hps_mem_conduit_end_mem_cs_n        (hps_memory_mem_cs_n),
    .emif_a10_hps_mem_conduit_end_mem_odt         (hps_memory_mem_odt),
    .emif_a10_hps_mem_conduit_end_mem_reset_n     (hps_memory_mem_reset_n),
    .emif_a10_hps_mem_conduit_end_mem_par         (hps_memory_mem_par),
    .emif_a10_hps_mem_conduit_end_mem_alert_n     (hps_memory_mem_alert_n),
    .emif_a10_hps_mem_conduit_end_mem_dqs         (hps_memory_mem_dqs),
    .emif_a10_hps_mem_conduit_end_mem_dqs_n       (hps_memory_mem_dqs_n),
    .emif_a10_hps_mem_conduit_end_mem_dq          (hps_memory_mem_dq),
    .emif_a10_hps_mem_conduit_end_mem_dbi_n       (hps_memory_mem_dbi_n),
    .emif_a10_hps_oct_conduit_end_oct_rzqin       (hps_memory_oct_rzqin),
    .emif_a10_hps_pll_ref_clk_clock_sink_clk      (emif_ref_clk)
);

endmodule